"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var express = require("express");
var logger_config_1 = require("../config/logger.config");
var mssql_service_1 = require("../db/mssql.service");
var mssql_config_1 = require("../config/mssql.config");
var mssql_init_1 = require("../db/mssql.init");
var redis_init_1 = require("../db/redis.init");
var mail_init_1 = require("../mail/mail.init");
var redis_service_1 = require("../db/redis.service");
var log4js = require("log4js");
var promises_shared_1 = require("../shared/promises.shared");
var find_process_task_1 = require("./find-process.task");
var file_manager_1 = require("../shared/file-manager");
var config_1 = require("../config/config");
var smtp_mail_1 = require("../mail/smtp.mail");
var node_ssh_1 = require("node-ssh");
log4js.configure(logger_config_1.LOGGER_CONFIG);
var logger = log4js.getLogger('Cleaner');
var RETRY = 3;
var ITEMS_PER_PAGE = 5;
var ROOT_KEY = "CleanerTaskData";
var IDATHA_SCRIPT = 'jobs/realm_job.sh';
var EMAILS = "amaravi@inconcertcc.com";
var PATHS = [
    config_1.SEMANCTIC_ANALYSIS_VIEW_FOLDER,
    config_1.TRANSCRIPTION_FOLDER,
    config_1.PATH_FOLDER_TEMP_NLU
];
(0, find_process_task_1.ProcessInRunning)().then(function (processRunning) {
    if (processRunning) {
        logger.info('[cleaner.task::Run] Found process running');
        return Promise.resolve(false);
    }
    return Run();
}).then(function (result) {
    logger.info('[cleaner.task::Run] Finished Cleaner Task:', result);
});
function Run() {
    logger.info('[cleaner.task::Run] Begin Cleaner Task');
    mssql_config_1.MSSQL_CONFIG.connectionTimeout = 300 * 1000;
    mssql_config_1.MSSQL_CONFIG.requestTimeout = 300 * 1000;
    var app = express();
    var sqlConn;
    var redisClient;
    var mailServer;
    var isConnectedEmailServer = false;
    return (0, promises_shared_1.DummyPromise)()
        .then(function (_) {
        return (0, redis_init_1.RedisInit)(app);
    })
        .then(function (_) {
        redisClient = app.get('redisClient');
        return true;
    })
        .then(function (_) {
        return (0, mssql_init_1.MsSqlInit)(app);
    })
        .then(function (_) {
        sqlConn = app.get('sqlConn');
        return true;
    })
        .then(function (_) {
        return (0, mail_init_1.MailInit)(app);
    })
        .then(function (mailConnected) {
        mailServer = app.get('mailserver');
        isConnectedEmailServer = mailConnected;
        return true;
    })
        .then(function (_) {
        return mssql_service_1.MSSql.GetVccCleanerConfig();
    })
        .then(function (vccs) {
        if (typeof vccs == 'object' && vccs.length > 0) {
            logger.info('[cleaner.task::Run] Found vccs:', vccs.length);
            var promises = [
                Promise.resolve(true),
                Promise.resolve(vccs)
            ];
            for (var _i = 0, vccs_1 = vccs; _i < vccs_1.length; _i++) {
                var row = vccs_1[_i];
                var loader = new DataLoader(row.vcc, row.deleteDataDays);
                promises.push(loader.Run());
            }
            return Promise.all(promises);
        }
        logger.debug('[cleaner.task::Run] Not found vccs');
        return [
            false
        ];
    })
        .then(function (results) {
        var promises = [];
        var foundData = results[0];
        if (foundData) {
            var vccs = results[1];
            promises.push(DatabaseCleanerHandler());
            promises.push(FileCleanerHandler(vccs));
            promises.push(IdathaCleanerHandler(vccs));
        }
        else {
            promises.push(Promise.resolve(false));
        }
        return Promise.all(promises);
    })
        .then(function (results) {
        logger.info('[cleaner.task::Run] Tasks cleanners result:', results);
        if (isConnectedEmailServer) {
            var emailSender = new EmailSender();
            return emailSender.Run();
        }
        return true;
    })
        .then(function (_) {
        return DeleteAllTasks();
    })
        .then(function (result) {
        sqlConn.close();
        redisClient.quit();
        mailServer.close();
        return result;
    })
        .catch(function (err) {
        logger.error('[cleaner.task::Run] Error:', err);
        if (sqlConn) {
            sqlConn.close();
        }
        if (redisClient) {
            redisClient.quit();
        }
        if (mailServer) {
            mailServer.close();
        }
        return false;
    });
}
var DataLoader = (function () {
    function DataLoader(vcc, days) {
        this.vcc = vcc;
        this.days = days;
    }
    DataLoader.prototype.Run = function () {
        var _this = this;
        return mssql_service_1.MSSql.GetCleanerData(this.vcc, this.days)
            .then(function (results) {
            return _this.ProcessData(results);
        }).catch(function (err) {
            logger.error('[cleaner.task::DataLoader->Run] Error:', err);
            return false;
        });
    };
    DataLoader.prototype.ProcessData = function (rows) {
        if (rows && rows.length > 0) {
            var evaluationPlans = rows[0];
            var studies = rows[1];
            var process_1 = rows[2];
            var processAsyncs = rows[3];
            var audios = rows[4];
            var asyncInteractions = rows[5];
            var promises = [];
            logger.info("[cleaner.task::DataLoader->ProcessData] Result for ".concat(this.vcc, " with days ").concat(this.days, ":"), JSON.stringify({
                plan: evaluationPlans.length,
                study: studies.length,
                process: process_1.length,
                processAsyncs: processAsyncs.length,
                audios: audios.length,
                asyncInteractions: asyncInteractions.length
            }));
            if (evaluationPlans.length > 0) {
                promises.push(this.SaveToRedis(evaluationPlans, 'evaluationPlans', 'id'));
            }
            if (studies.length > 0) {
                promises.push(this.SaveToRedis(studies, 'studies', 'name'));
            }
            if (process_1.length > 0) {
                promises.push(this.SaveToRedis(process_1, 'process', 'name'));
            }
            if (processAsyncs.length > 0) {
                promises.push(this.SaveToRedis(processAsyncs, 'processAsyncs', 'processId'));
            }
            if (audios.length > 0) {
                promises.push(this.SaveToRedis(audios, 'audios', 'id', {
                    retry: 0
                }));
            }
            if (asyncInteractions.length > 0) {
                promises.push(this.SaveToRedis(asyncInteractions, 'asyncInteractions', 'id'));
            }
            return Promise.all(promises).then(function (results) {
                return !results.includes(false);
            });
        }
        return Promise.resolve(false);
    };
    DataLoader.prototype.SaveToRedis = function (rows, key, id, mixin) {
        if (mixin === void 0) { mixin = {}; }
        return redis_service_1.Redis.SaveCleanerData("".concat(ROOT_KEY, ":").concat(key), id, this.vcc, mixin, rows);
    };
    return DataLoader;
}());
var AudioCleaner = (function () {
    function AudioCleaner() {
    }
    AudioCleaner.prototype.Run = function () {
        var _this = this;
        logger.info('[cleaner.task::AudioCleaner->Run] Begin read audio cleaner');
        return (0, promises_shared_1.DummyPromise)().then(function (_) {
            return _this.Read(0, ITEMS_PER_PAGE);
        });
    };
    AudioCleaner.prototype.Read = function (start, end) {
        var _this = this;
        return (0, promises_shared_1.DummyPromise)().then(function (_) {
            return redis_service_1.Redis.LRange("".concat(ROOT_KEY, ":audios:Keys"), start, end - 1);
        }).then(function (keys) {
            var promises = [];
            if (keys && keys.length > 0) {
                logger.info('[cleaner.task::AudioCleaner->Read] Found audio keys:', keys.length);
                promises.push(Promise.resolve(true));
                promises.push(redis_service_1.Redis.GetCleanerData("".concat(ROOT_KEY, ":audios"), keys));
            }
            else {
                promises.push(Promise.resolve(false));
                logger.debug('[cleaner.task::AudioCleaner->Read] Not found audio keys:', keys);
            }
            return Promise.all(promises);
        }).then(function (results) {
            var found = results[0];
            var promises = [Promise.resolve(found)];
            if (found) {
                var _audios = results[1];
                for (var _i = 0, _audios_1 = _audios; _i < _audios_1.length; _i++) {
                    var a = _audios_1[_i];
                    var audio = JSON.parse(a);
                    promises.push(_this.Clean(audio));
                }
            }
            return Promise.all(promises);
        }).then(function (results) {
            if (results[0]) {
                return _this.Read(start + ITEMS_PER_PAGE, end + ITEMS_PER_PAGE);
            }
            return true;
        });
    };
    AudioCleaner.prototype.Clean = function (audio, message) {
        var _this = this;
        if (message === void 0) { message = ''; }
        var path = "".concat(config_1.PATH_FOLDER_PROCESS_AUDIO_PLAY, "/").concat(audio.vcc, "/").concat(audio.fileName);
        logger.info('[cleaner.task::AudioCleaner->Clean] Deleting audio:', path);
        if (audio.retry < RETRY) {
            return (0, promises_shared_1.DummyPromise)().then(function (_) {
                if (audio.fileName) {
                    return (0, file_manager_1.ExistInFileSystem)(path);
                }
                return false;
            })
                .then(function (exists) {
                if (exists) {
                    return (0, file_manager_1.DeleteFile)(path);
                }
                return true;
            })
                .then(function (deleted) {
                logger.info("[cleaner.task::AudioCleaner->Clean] Deleted audio ".concat(path, ":"), deleted);
                var promises = [Promise.resolve(deleted)];
                if (deleted) {
                    promises.push(redis_service_1.Redis.DeleteCleanerData("".concat(ROOT_KEY, ":audios"), "".concat(audio.vcc, ":").concat(audio.id)));
                    promises.push(mssql_service_1.MSSql.DeleteInteraction(audio.vcc, audio.id, true));
                }
                return Promise.all(promises);
            }).then(function (results) {
                var deleted = results[0];
                if (!deleted) {
                    audio.retry += 1;
                    return _this.Clean(Object.assign({}, audio), "Error desconocido al eliminar el audio ".concat(audio.id));
                }
                return !results.includes(false);
            }).catch(function (err) {
                logger.error("[cleaner.task::AudioCleaner->Clean] Error on delete audio ".concat(audio.id, " for ").concat(audio.vcc, ":"), err);
                audio.retry += 1;
                return _this.Clean(Object.assign({}, audio), getErrorMessage(err));
            });
        }
        return SaveCleanerError({
            vcc: audio.vcc,
            description: message,
            raw: JSON.stringify(audio),
            process: 'Speech binarios [audio]'
        });
    };
    return AudioCleaner;
}());
function DatabaseCleanerHandler() {
    logger.info('[cleaner.task::DatabaseCleanerHandler] Begin database cleaner');
    var promises = [];
    var evaluationPlans = new DatabaseCleaner('evaluationPlans', 'id', 1);
    var studies = new DatabaseCleaner('studies', 'name', 2);
    var process = new DatabaseCleaner('process', 'name', 3);
    var processAsyncs = new DatabaseCleaner('processAsyncs', 'processId', 4);
    var asyncInteractions = new DatabaseCleaner('asyncInteractions', 'id', 5);
    var audioCleaner = new AudioCleaner();
    promises.push(evaluationPlans.Run());
    promises.push(studies.Run());
    promises.push(process.Run());
    promises.push(processAsyncs.Run());
    promises.push(asyncInteractions.Run());
    promises.push(audioCleaner.Run());
    return (0, promises_shared_1.DummyPromise)().then(function (_) {
        return Promise.all(promises);
    })
        .then(function (results) {
        var description = '';
        var result = !results.includes(false);
        if (result) {
            description = 'Finalizado correctamente';
        }
        else {
            description = 'Finalizado con errores';
        }
        return SaveCleanerSummary('speech_database', result, description);
    }).catch(function (err) {
        logger.error("[cleaner.task::DatabaseCleanerHandler] Error on clear in speech database:", err);
        return SaveCleanerSummary('speech_database', false, getErrorMessage(err));
    });
}
var DatabaseCleaner = (function () {
    function DatabaseCleaner(key, idKey, type) {
        this.key = key;
        this.idKey = idKey;
        this.type = type;
    }
    DatabaseCleaner.prototype.Run = function () {
        var _this = this;
        logger.info('[cleaner.task::DatabaseCleaner->Run] Begin database cleaner for:', this.key);
        return (0, promises_shared_1.DummyPromise)().then(function (_) {
            return _this.Read(0, ITEMS_PER_PAGE);
        });
    };
    DatabaseCleaner.prototype.Read = function (start, end) {
        var _this = this;
        return (0, promises_shared_1.DummyPromise)().then(function (_) {
            return redis_service_1.Redis.LRange("".concat(ROOT_KEY, ":").concat(_this.key, ":Keys"), start, end - 1);
        }).then(function (keys) {
            var promises = [];
            if (keys && keys.length > 0) {
                logger.info("[cleaner.task::DatabaseCleaner->Read] Found ".concat(_this.key, " keys:"), keys.length);
                promises.push(Promise.resolve(true));
                promises.push(redis_service_1.Redis.GetCleanerData("".concat(ROOT_KEY, ":").concat(_this.key), keys));
            }
            else {
                promises.push(Promise.resolve(false));
                logger.debug("[cleaner.task::DatabaseCleaner->Read] Not found ".concat(_this.key, " keys:"), keys);
            }
            return Promise.all(promises);
        }).then(function (results) {
            var found = results[0];
            var promises = [Promise.resolve(found)];
            if (found) {
                var _items = results[1];
                for (var _i = 0, _items_1 = _items; _i < _items_1.length; _i++) {
                    var i = _items_1[_i];
                    var item = JSON.parse(i);
                    if (item) {
                        promises.push(_this.Clean(item));
                    }
                }
            }
            return Promise.all(promises);
        }).then(function (results) {
            if (results[0]) {
                return _this.Read(start + ITEMS_PER_PAGE, end + ITEMS_PER_PAGE);
            }
            return true;
        }).catch(function (err) {
            logger.info("[cleaner.task::DatabaseCleaner->Read] Error on read ".concat(_this.key), err);
            return false;
        });
    };
    DatabaseCleaner.prototype.Clean = function (item, retry, message) {
        var _this = this;
        if (retry === void 0) { retry = 0; }
        if (message === void 0) { message = ''; }
        logger.info("[cleaner.task::DatabaseCleaner->Clean] Deleting ".concat(this.key, ":"), item[this.idKey]);
        if (retry < RETRY) {
            return (0, promises_shared_1.DummyPromise)().then(function (_) {
                switch (_this.type) {
                    case 1:
                        return mssql_service_1.MSSql.DeleteEvaluationPlan(item.vcc, item[_this.idKey]);
                    case 2:
                        return mssql_service_1.MSSql.DeleteStudy(item.vcc, item[_this.idKey]);
                    case 3:
                        return mssql_service_1.MSSql.DeleteProcess(item.vcc, item[_this.idKey]);
                    case 4:
                        return mssql_service_1.MSSql.DeleteProcessAsync(item.vcc, item[_this.idKey]);
                    case 5:
                        return mssql_service_1.MSSql.DeleteInteraction(item.vcc, item[_this.idKey], false);
                    default: break;
                }
                return false;
            }).then(function (deleted) {
                logger.info("[cleaner.task::DatabaseCleaner->Clean] Deleted ".concat(_this.key, " ").concat(item[_this.idKey], ":"), deleted);
                var promises = [Promise.resolve(deleted)];
                if (deleted) {
                    promises.push(redis_service_1.Redis.DeleteCleanerData("".concat(ROOT_KEY, ":").concat(_this.key), "".concat(item.vcc, ":").concat(item[_this.idKey])));
                }
                return Promise.all(promises);
            }).then(function (results) {
                var deleted = results[0];
                if (!deleted) {
                    return _this.Clean(item, retry + 1, "Error desconocido al eliminar ".concat(_this.key, " : ").concat(item[_this.idKey]));
                }
                return !results.includes(false);
            }).catch(function (err) {
                logger.error("[cleaner.task::DatabaseCleaner->Clean] Error on delete ".concat(_this.key, " ").concat(item[_this.idKey], " for ").concat(item.vcc, ":"), err);
                return _this.Clean(item, retry + 1, getErrorMessage(err));
            });
        }
        return SaveCleanerError({
            vcc: item.vcc,
            description: message,
            raw: JSON.stringify(item),
            process: 'Speech base de datos'
        });
    };
    return DatabaseCleaner;
}());
var EmailSender = (function () {
    function EmailSender() {
    }
    EmailSender.prototype.Run = function () {
        var _this = this;
        logger.info("[cleaner.task::EmailSender->Run] Begin");
        return (0, promises_shared_1.DummyPromise)().then(function (_) {
            return redis_service_1.Redis.LRange("".concat(ROOT_KEY, ":errors"), 0, -1);
        }).then(function (results) {
            if (results && results.length > 0) {
                logger.info("[cleaner.task::EmailSender->Run] Found errors:", results.length);
                return _this.StartSend(results);
            }
            logger.info("[cleaner.task::EmailSender->Run] Not found errors");
            return true;
        });
    };
    EmailSender.prototype.StartSend = function (rows) {
        var _this = this;
        return (0, promises_shared_1.DummyPromise)().then(function (_) {
            return mssql_service_1.MSSql.GetVersion();
        }).then(function (version) {
            logger.info("[cleaner.task::EmailSender->StartSend] installationId:", version.installationId);
            return _this.Send(rows, version.installationId);
        }).catch(function (err) {
            logger.error("[cleaner.task::EmailSender->StartSend] Error on get installationId and send email:", err);
            return false;
        });
    };
    EmailSender.prototype.Send = function (rows, installationId) {
        var errors = [];
        for (var _i = 0, rows_1 = rows; _i < rows_1.length; _i++) {
            var row = rows_1[_i];
            var error = JSON.parse(row);
            errors.push("\n           <tr>\n           <td>".concat(error.vcc, "</td>\n           <td>").concat(error.process, "</td>\n           <td>").concat(error.description, "</td>\n           <td>").concat(error.raw, "</td>\n           </tr>\n           "));
        }
        logger.info("[cleaner.task::EmailSender->Send] Send email");
        var template = "\n        <h3>Hola, el proceso de eliminaci&oacute;n ha finalizado con errores</h3>\n        <p>Los siguientes objetos no se han eliminado:</p>\n        <br>\n        <table border=\"1\">\n      <thead>\n      <tr>\n        <th>VCC</th>\n        <th>Proceso</th>\n        <th>Descripci&oacute;n</th>\n        <th>Valor(raw)</th>\n        </tr>\n      </thead> \n      <tbody>\n      ".concat(errors.join(' '), "\n      </tbody> \n        </table>\n        ");
        return (0, promises_shared_1.DummyPromise)().then(function (_) {
            return (0, smtp_mail_1.Send)(EMAILS, "Error de eliminaci\u00F3n en el ambiente ".concat(installationId), template);
        }).then(function (success) {
            logger.info("[cleaner.task::EmailSender->Send] Result send email:", success);
            return success;
        }).catch(function (err) {
            logger.error("[cleaner.task::EmailSender->Send] Error on send email:", err);
            return false;
        });
    };
    return EmailSender;
}());
function FileCleanerHandler(vccs) {
    var promises = [];
    for (var _i = 0, vccs_2 = vccs; _i < vccs_2.length; _i++) {
        var row = vccs_2[_i];
        var fileCleaner = new FileCleaner(row.vcc, row.deleteDataDays);
        promises.push(fileCleaner.Run());
    }
    return (0, promises_shared_1.DummyPromise)().then(function (_) {
        return Promise.all(promises);
    }).then(function (results) {
        var description = '';
        var result = !results.includes(false);
        if (result) {
            description = 'Finalizado correctamente';
        }
        else {
            description = 'Finalizado con errores';
        }
        return SaveCleanerSummary('speech_files', result, description);
    }).catch(function (err) {
        logger.error("[cleaner.task::FileCleanerHandler] Error on clear files:", err);
        return SaveCleanerSummary('speech_files', false, getErrorMessage(err));
    });
}
var FileCleaner = (function () {
    function FileCleaner(vcc, days) {
        this.vcc = vcc;
        this.days = days;
        this.seconds = this.days * 24 * 60 * 60;
    }
    FileCleaner.prototype.Run = function () {
        var _this = this;
        var promises = [];
        for (var _i = 0, PATHS_1 = PATHS; _i < PATHS_1.length; _i++) {
            var path = PATHS_1[_i];
            promises.push(this.Clean("".concat(path, "/").concat(this.vcc)));
        }
        return Promise.all(promises).then(function (results) {
            logger.debug("[cleaner.task::FileCleaner->Run] Clean results for ".concat(_this.vcc, ":"), results);
            return !results.includes(false);
        });
    };
    FileCleaner.prototype.Clean = function (path, retry, message) {
        var _this = this;
        if (retry === void 0) { retry = 0; }
        if (message === void 0) { message = ''; }
        logger.info("[cleaner.task::FileCleaner->Clean] Deleting path:", path);
        if (retry < RETRY) {
            return (0, promises_shared_1.DummyPromise)().then(function (_) {
                return (0, file_manager_1.ExistInFileSystem)(path);
            }).then(function (found) {
                var promises = [Promise.resolve(found)];
                if (found) {
                    logger.info("[cleaner.task::FileCleaner->Clean] Found path ".concat(path));
                    promises.push((0, file_manager_1.CleanupTempFile)(path, _this.seconds));
                }
                logger.info("[cleaner.task::FileCleaner->Clean] Not found path ".concat(path));
                return Promise.all(promises);
            })
                .then(function (results) {
                var found = results[1];
                if (found) {
                    var deleted = results[1];
                    logger.info("[cleaner.task::FileCleaner->Clean] Deleted path ".concat(path, ":"), deleted);
                    if (!deleted) {
                        return _this.Clean(path, retry + 1, "Error desconocido al eliminar la carpeta ".concat(path));
                    }
                    return deleted;
                }
                return true;
            })
                .catch(function (err) {
                logger.error("[cleaner.task::FileCleaner->Clean] Error on delete path ".concat(path, ":"), err);
                return _this.Clean(path, retry + 1, getErrorMessage(err));
                ;
            });
        }
        return SaveCleanerError({
            vcc: this.vcc,
            description: message,
            raw: '',
            process: 'Speech binarios'
        });
    };
    return FileCleaner;
}());
function IdathaCleanerHandler(vccs) {
    if (vccs.length == 0) {
        return Promise.resolve(true);
    }
    return (0, promises_shared_1.DummyPromise)().then(function (_) {
        var row = vccs.pop();
        var idathaCleaner = new IdathaCleaner(row.vcc, row.deleteDataDays);
        return idathaCleaner.Run();
    })
        .then(function (result) {
        var description = '';
        if (result) {
            description = 'Finalizado correctamente';
        }
        else {
            description = 'Finalizado con errores';
        }
        return SaveCleanerSummary('idatha', result, description);
    })
        .then(function (_) {
        return IdathaCleanerHandler(vccs);
    })
        .catch(function (err) {
        logger.error("[cleaner.task::IdathaCleanerHandler] Error on clear in idatha:", err);
        return SaveCleanerSummary('idatha', false, getErrorMessage(err));
    });
}
var IdathaCleaner = (function () {
    function IdathaCleaner(vcc, days) {
        this.vcc = vcc;
        this.days = days;
        var d = new Date();
        var add = 0;
        if (this.days < 90) {
            add = 90;
        }
        d.setDate(d.getDate() - (this.days + add));
        this.date = d.toISOString().substring(0, 10);
    }
    IdathaCleaner.prototype.Run = function (retry, message) {
        var _this = this;
        if (retry === void 0) { retry = 0; }
        if (message === void 0) { message = ''; }
        var cmd = "".concat(IDATHA_SCRIPT, " ").concat(this.date, " ").concat(this.vcc);
        if (retry < RETRY) {
            var ssh_1 = new node_ssh_1.NodeSSH();
            return (0, promises_shared_1.DummyPromise)().then(function (_) {
                return ssh_1.connect({
                    host: config_1.IDATHA_IP,
                    username: config_1.IDATHA_USER,
                    password: config_1.IDATHA_PASSWORD,
                    port: config_1.IDATHA_SSH_PORT,
                    readyTimeout: 99999
                });
            }).then(function (_) {
                if (ssh_1.isConnected) {
                    logger.info('[cleaner.task::IdathaCleaner->Run] Run command in idatha:', cmd);
                    return ssh_1.execCommand(cmd, { cwd: '/home/admon/in_concert_speech_analytics/' });
                }
                logger.error('[cleaner.task::IdathaCleaner->Run] Not connected to idatha');
                return null;
            })
                .then(function (response) {
                ssh_1.dispose();
                if (typeof response == 'object') {
                    if (response.stdout) {
                        try {
                            var output = JSON.parse(response.stdout);
                            logger.debug("[cleaner.task::IdathaCleaner->Run] Output for command ".concat(cmd, ":"), output);
                            if (typeof output.deleted_data == 'object') {
                                return { state: true };
                            }
                            return { state: false, message: "Error desconocido al eliminar el realm ".concat(_this.vcc, ", stdout is : ").concat(JSON.stringify(output)) };
                        }
                        catch (err) {
                            return { state: false, message: getErrorMessage(err) };
                        }
                    }
                    return { state: false, message: response.stderr };
                }
                return { state: false, message: 'Connection fail' };
            })
                .then(function (result) {
                if (!result.state) {
                    return _this.Run(retry + 1, result.message);
                }
                return result.state;
            })
                .catch(function (error) {
                ssh_1.dispose();
                var error_message = getErrorMessage(error);
                logger.error('[cleaner.task::IdathaCleaner->Run] Error on connect to idatha:', error_message);
                return _this.Run(retry + 1, error_message);
            });
        }
        return SaveCleanerError({
            vcc: this.vcc,
            description: message,
            raw: cmd,
            process: 'idatha'
        });
    };
    return IdathaCleaner;
}());
function SaveCleanerError(data, returnValue) {
    if (returnValue === void 0) { returnValue = false; }
    logger.debug('[cleaner.task::SaveCleanerError] Saving error for:', data.vcc);
    return (0, promises_shared_1.DummyPromise)().then(function (_) {
        return redis_service_1.Redis.SaveCleanerError("".concat(ROOT_KEY, ":errors"), data);
    }).then(function (_) {
        return returnValue;
    });
}
function SaveCleanerSummary(task, status, description) {
    logger.debug('[cleaner.task::SaveCleanerSummary] Saving summary for task:', task);
    return mssql_service_1.MSSql.SaveCleanerSummary(task, status, description.length > 250 ? description.substring(0, 250) : description);
}
function DeleteAllTasks() {
    var tasks = [
        "".concat(ROOT_KEY, ":evaluationPlans"),
        "".concat(ROOT_KEY, ":evaluationPlans:Keys"),
        "".concat(ROOT_KEY, ":studies"),
        "".concat(ROOT_KEY, ":studies:Keys"),
        "".concat(ROOT_KEY, ":asyncInteractions"),
        "".concat(ROOT_KEY, ":asyncInteractions:Keys"),
        "".concat(ROOT_KEY, ":audios"),
        "".concat(ROOT_KEY, ":audios:Keys"),
        "".concat(ROOT_KEY, ":process"),
        "".concat(ROOT_KEY, ":process:Keys"),
        "".concat(ROOT_KEY, ":processAsyncs"),
        "".concat(ROOT_KEY, ":processAsyncs:Keys"),
        "".concat(ROOT_KEY, ":errors"),
    ];
    return redis_service_1.Redis.DeleteAllCleanerTasks(tasks).then(function (result) {
        logger.info('[cleaner.task::DeleteAllTasks] Result for delete redis task:', result);
        return true;
    }).catch(function (err) {
        logger.error('[cleaner.task::DeleteAllTasks] Error on clear redis tasks:', err);
        return false;
    });
}
function getErrorMessage(err) {
    return (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
}
